/*
 * @Author: PoJun
 * @Date: 2022-02-28 10:18:24
 * @LastEditors: PoJun
 * @LastEditTime: 2023-06-09 12:17:10
 * @Message: Do not edit
 */
import axios from "axios";
import store from "@/store/index.js";
import Vue from "vue";
import router from "@/router";
import { encodeURL, mergeURL } from "./jointURL";
import { showLoading, hideLoading } from "@/utils/utils";
// 创建axios实例
/**
 * 可以做一些 axios 的通用配置
 * 下面 defaultConfig 是一个例子
 */
const defaultConfig = {
    showLoading: true, //默认请求显示loading
    baseURL: process.env.VUE_APP_RUNTIME_ENV == "development" ? "/api" : process.env.VUE_APP_BASE_API, //代理域名路径
    timeout: 15000, // 请求超时时间
    headers: {
        get: {
            "Content-Type": "application/x-www-form-urlencoded;charset=utf-8",
            type: "web",
        },
        post: {
            "Content-Type": "application/json;charset=utf-8",
            type: "web",
        },
    },
    // 是否跨站点访问控制请求
    withCredentials: true,
    validateStatus(status) {
        // 使用async-await，处理reject情况较为繁琐，所以全部返回resolve，在业务代码中处理异常
        return status < 400; // 状态码大于 400 开始 reject (报错)
        // return true;
    },
    transformResponse: [
        data => {
            if (typeof data === "string" && data.startsWith("{")) {
                data = JSON.parse(data);
            }
            return data;
        },
    ],
};
let configCache = null;
// request拦截器
axios.interceptors.request.use(
    req => {
        if (req.showLoading) {
            showLoading();
            configCache = req;
        }

        if (req?.auth) {
            req.headers.satoken = store.state.vSatoken;
        }

        const controller = new AbortController(); // 每个请求时都新生成一个AbortController实例
        req.signal = controller.signal; // 设置请求的signal字段为new AbortController()的signal
        store.commit("addVApiController", controller);
        return req;
    },
    error => {
        if (configCache.showLoading) {
            hideLoading();
            configCache = null;
        }
        return Promise.reject(error);
    }
);
// respone拦截器
axios.interceptors.response.use(
    response => {
        /**
         * code为非200是抛错 可结合自己业务进行修改
         */
        const status = response.status,
            config = response.config;
        if (response.config.showLoading) {
            hideLoading();
        }
        if (status === 200) {
            if (config.notIntercept) {
                return response.data;
            }
            const { data, code, message } = response.data;

            if (code === 200 || code === 0) {
                if (config.showTips) {
                    //showTips,针对增删改情况，成功也需要提示的场景
                    Vue.prototype.$message.success(message);
                }
                return data;
            } else if (code === 401 || code === 1) {
                // 返回登录页面
                router.replace({ path: "/login" });
                // 给未登录的提示加一个key，保证多个请求相差无几完成时不回弹出多个未登录，
                Vue.prototype.$message.error({ content: message, key: "noLogin" });
                return Promise.reject(new Error(message));
            } else {
                Vue.prototype.$message.error(message);
                return Promise.reject(new Error(message));
            }
        } else {
            Vue.prototype.$message.error(response.statusText);
            return Promise.reject(new Error(response.statusText));
        }
    },
    error => {
        // if (configCache&&configCache.showLoading) {
        // todo 此处有BUG，先想想。
        hideLoading();
        configCache = null;
        // }
        return Promise.reject(error);
    }
);

// 封装 get 请求
export const $get = ({ url, reqConfig, params, pathAdd, headers }) => {
    reqConfig = reqConfig ? { ...defaultConfig, ...reqConfig } : { ...defaultConfig };
    if (headers) {
        reqConfig.headers.get = { ...reqConfig.headers.get, ...headers };
    }
    return axios.get(encodeURL(mergeURL(url, pathAdd), params), reqConfig, headers);
};

// 封装 post 请求
export const $post = ({ url, reqConfig, params, pathAdd, data, headers }) => {
    reqConfig = reqConfig ? { ...defaultConfig, ...reqConfig } : { ...defaultConfig };
    if (headers) {
        reqConfig.headers.post = { ...reqConfig.headers.post, ...headers };
    }
    return axios.post(encodeURL(mergeURL(url, pathAdd), params), data, reqConfig, headers);
};
