/*
 * @Author: PoJun
 * @Date: 2022-04-08 17:05:49
 * @LastEditors: PoJun
 * @LastEditTime: 2023-05-31 16:28:37
 */
import Vue from "vue";
import VueRouter from "vue-router";
import store from "@/store/index.js";
import NProgress from "nprogress";
import "nprogress/nprogress.css";

import { permissionsRoutes } from "./routes";

//获取原型对象上的push函数
const originalPush = VueRouter.prototype.push;
//修改原型对象中的push方法
VueRouter.prototype.push = function push(location) {
    return originalPush.call(this, location).catch(err => err);
};

Vue.use(VueRouter);
// 静态路由
const router = new VueRouter({
    routes: [
        {
            path: "/Layout",
            name: "Layout",
            component: () => import("@/layout/page.vue"),
            children: permissionsRoutes,
            redirect: "/merchants",
        },
        {
            path: "/login",
            name: "login",
            component: () => import("@/views/login/index.vue"),
            meta: { title: "登录" },
        },
        {
            path: "*",
            redirect: "/login",
        },
    ],
});

router.beforeEach(async (to, from, next) => {
    NProgress.start();
    if (to.meta?.title) {
        document.title = to.meta.title; // 某些详情页面不需要修改title
    }
    // 只需要校验是否登录就行了
    if (store.state.vIsLogin) {
        next();
    } else {
        if (to.path !== "/login") {
            next("/login");
        } else {
            next();
        }
    }
});

router.afterEach(() => {
    NProgress.done();
});

export default router;
