/*
 * @Author: PoJun
 * @Date: 2022-02-25 09:15:23
 * @LastEditors: PoJun
 * @LastEditTime: 2023-05-31 10:57:32
 * @Message: Do not edit
 */
import Vue from "vue";

/**
 * 返回枚举的name字段
 * @param {object} e 枚举类型对象
 * @returns 枚举的name
 */
export const formatEnum = e => {
    if (!e) {
        e = { key: "", name: "" };
    }
    return e.name || "-";
};

/**
 * 时间格式化
 * yyyy:mm:dd|yyyy:mm|yyyy年mm月dd日|yyyy年mm月dd日 hh时MM分等,可自定义组合
 * @param {date} dateTime 需要格式化的时间
 * @param {string} fmt 需要格式化的目标模板
 * @param {boolean} fmt 当dateTime为空时是否格式化当前时间
 * @returns 根据fmt返回相应的时间
 */
export const formatDate = (dateTime = null, fmt = "yyyy-mm-dd hh:MM:ss", fmtCurrentDate = false) => {
    if (!fmtCurrentDate && !dateTime) {
        return "";
    }
    // 如果为null,则格式化当前时间，如果需要的话
    if (!dateTime) {
        dateTime = Number(new Date());
    }
    // 如果dateTime长度为10或者13，则为秒和毫秒的时间戳，如果超过13位，则为其他的时间格式
    if (dateTime.toString().length == 10) {
        dateTime *= 1000;
    }
    let date = new Date(dateTime);
    let ret;
    let opt = {
        "y+": date.getFullYear().toString(), // 年
        "m+": (date.getMonth() + 1).toString(), // 月
        "d+": date.getDate().toString(), // 日
        "h+": date.getHours().toString(), // 时
        "M+": date.getMinutes().toString(), // 分
        "s+": date.getSeconds().toString(), // 秒
        // 有其他格式化字符需求可以继续添加，必须转化成字符串
    };
    for (let k in opt) {
        ret = new RegExp("(" + k + ")").exec(fmt);
        if (ret) {
            fmt = fmt.replace(ret[1], ret[1].length == 1 ? opt[k] : opt[k].padStart(ret[1].length, "0"));
        }
    }
    return fmt;
};

/**
 * 浮点相加
 * @param {number} float1 加数
 * @param {number} float2 加数
 * @param {number} scale 数据精度（最大小数位数）
 * @returns 和
 */
export const sumFloat = (float1, float2, scale = 4) => {
    let s = Math.pow(10, scale);
    return (float1 * s + float2 * s) / s;
};
/**
 * 生成随机字符串
 * @param len  随机数长度，默认32位
 * @returns {string}
 */
export const randomString = function (len) {
    len = len || 32;
    /****默认去掉了容易混淆的字符oOLl,9gq,Vv,Uu,I1****/
    //let $chars = "ABCDEFGHJKMNPQRSTWXYZabcdefhijkmnprstwxyz2345678",
    let $chars = "ABCDEFGHJKMNPQRSTWXYZabcdefhijkmnprstwxyz",
        maxPos = $chars.length,
        pwd = "";
    for (let i = 0; i < len; i++) {
        pwd += $chars.charAt(Math.floor(Math.random() * maxPos));
    }
    return pwd;
};
/**
 * 获取指定名字最近父组件
 * @param {sting} componentName 组件名字
 * @returns 指定组件对象
 * @tips 调用方法 getParentComponent("XXX").call(this)
 */
export const getParentComponent = function (componentName) {
    let component = null;
    let parent = this.$parent;
    while (parent && !component) {
        if (parent.$options.name === componentName) {
            component = parent;
        }
        parent = parent.$parent;
    }
    return component;
};
/**
 * 获取url,指定参数
 * @param name
 * @returns {string}
 */
export function getQueryString(name) {
    let reg = new RegExp("(^|&)" + name + "=([^&]*)(&|$)", "i");
    let r = window.location.search.substr(1).match(reg);
    if (r != null) {
        return decodeURI(r[2]);
    }
    return null;
}

/**
 * 根据路径获取对象深层值
 * @param {object} obj 存储值的对象
 * @param {string} path 目标值在对象中的路径 eg: emun.key
 * @returns 目标值
 */
export const getObjDeepValue = (obj, path) => {
    if (!obj || !path) {
        return "";
    }
    const patchs = path.split(".");
    return patchs.reduce((total, cur) => {
        return total && total[cur] ? total[cur] : "";
    }, obj);
};

/**
 * @desc 函数防抖
 * @param func 目标函数
 * @param wait 延迟执行毫秒数
 * @param immediate true - 立即执行， false - 延迟执行
 *   立即执行版的意思是触发事件后函数会立即执行，然后 n 秒内不触发事件才能继续执行函数的效果
 非立即执行版的意思是触发事件后函数不会立即执行，而是在 n 秒后执行，如果在 n 秒内又触发了事件，则会重新计算函数执行时间。
 */
export const debounce = (func, wait, immediate) => {
    let timer;
    return function () {
        let context = this;
        let args = arguments;

        if (timer) {
            clearTimeout(timer);
        }
        if (immediate) {
            let callNow = !timer;
            timer = setTimeout(() => {
                timer = null;
            }, wait);
            if (callNow) {
                func.apply(context, args);
            }
        } else {
            timer = setTimeout(() => {
                func.apply(context, args);
            }, wait);
        }
    };
};

// 当前正在请求的数量
let needLoadingRequestCount = 0;

// 显示loading
export const showLoading = () => {
    // 后面这个判断很重要，因为关闭时加了抖动，此时loading对象可能还存在，
    // 但needLoadingRequestCount已经变成0.避免这种情况下会重新创建个loading
    console.log(needLoadingRequestCount);
    Vue.prototype.$loading.show();

    needLoadingRequestCount++;
};

// 隐藏loading
export const hideLoading = () => {
    needLoadingRequestCount--;
    needLoadingRequestCount = Math.max(needLoadingRequestCount, 0); // 做个保护
    if (needLoadingRequestCount === 0) {
        // 关闭loading
        toHideLoading();
    }
};

// 防抖：将 300ms 间隔内的关闭 loading 便合并为一次。防止连续请求时， loading闪烁的问题。
let toHideLoading = debounce(() => {
    Vue.prototype.$loading.hide();
}, 300);
